package cc.fascinated.model.user;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.Setter;
import lombok.ToString;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.UUID;

/**
 * @author Fascinated (fascinated7)
 */
@RequiredArgsConstructor
@Getter
@Setter
@ToString
@Document("user")
public class User {
    /**
     * The ID of the user.
     */
    @Id
    private final UUID id;

    /**
     * The username of the user.
     * <p>
     * Usually their Steam name.
     * </p>
     */
    @Indexed
    private String username;

    /**
     * The ID of the users steam profile.
     */
    @Indexed(unique = true)
    private String steamId;

    /**
     * Whether the user has logged into the website.
     * <p>
     * This is used to determine if we should track their profiles or not.
     * If they haven't logged in, we don't want to track their profiles.
     * </p>
     */
    @JsonIgnore
    public boolean hasLoggedIn;

    /**
     * The user's ScoreSaber account.
     */
    public ScoreSaberAccount scoresaberAccount;
}
